# Flytekit ONNX ScikitLearn Plugin

This plugin allows you to generate ONNX models from your ScikitLearn models.

To install the plugin, run the following command:

```
pip install flytekitplugins-onnxscikitlearn
```
